
/******************************************************************************
 * Copyright (c) 2003 Palm, Inc. or its subsidiaries.
 * All rights reserved.

*****************************************************************************/

/**
 * @file  PalmChars.h
 * @version 1.0
 * @date  02/29/2002
 *
 * Contains Palm-specific virtual characters.
 *
 * Five-way navigation macros and values for key states are included
 * in this file.
 *
 * <hr>
 */

#ifndef __PALMCHARS_H__
#define __PALMCHARS_H__

#include <Chars.h>

#if (vchrPalmMin != 0x0500) || (vchrPalmMax != 0x05FF)
#error "please check Palm vchr range or update the above assertion"
#endif

// To match PalmOS 5.1 definition in Chars.h.
#ifndef vchrHard5
#define vchrHard5     0x0214
#endif

// The keyBit mask used for polling the 5th hard key.
#ifndef keyBitHard5
#define keyBitHard5     0x2000
#endif

/** Silk screen clock button virtual character.
 * When handled by the system, it will launch the clock pop-up dialog.
 */
#define vchrSilkClock            (vchrPalmMin + 0)
/** Clock virtual character.
 * When handled by the system, it will launch the clock pop-up dialog.
 */
#define vchrClock                (vchrPalmMin + 1)
/** Pop-up brightness virtual character.
 * When handled by the system, it will launch the brightness pop-up dialog.
 */
#define vchrPopupBrightness      (vchrPalmMin + 2)
/** Five way navigation virtual character.
 * This character indicates that the five way navigation states have
changed.
 */
#define vchrNavChange            (vchrPalmMin + 3)
/** Camera shutter virtual character.
 * Generated by the camera shutter button. Currently only available on
Zire71.
 */
#define vchrCameraShutter   (vchrPalmMin + 8)
/** Record button virtual character.
 * On Tungsten T, this button is located below the microphone. On Tungsten W
 * and Tungsten C, the button is generally placed on the headset.
 */
#define vchrHardRecord    (vchrHard5)

// The following group of characters are specific for Tungsten W
#define vchrDeviceSpecificChar  (vchrPalmMin+20)
/** Tungsten W virtual character.
 * This character indicates that 3rd Hard key is down.  Used to check for press and hold event.
 */
#define vchrHard3Down    (vchrDeviceSpecificChar + 0)
/** Tungsten W virtual character.
 * This character indicates that 4th Hard key is down.  Used to check for press and hold event.
 */
#define vchrHard4Down    (vchrDeviceSpecificChar + 1)
/** Tungsten W virtual character.
 * This character indicates that there is an incoming call.
 */
#define vchrDeviceIncomingCall  (vchrDeviceSpecificChar + 2)
/** Tungsten W virtual character.
 * This character indicates that the phone has been powered on
 */
#define vchrTelDevicePowerOn  (vchrDeviceSpecificChar + 3)
/** Tungsten W virtual character.
 * This character indicates that the Favorite Application button has been pressed.
 * The button is UP at this point.
 */
#define vchrMyFavoriteApplication   (vchrDeviceSpecificChar + 4)
/** Tungsten W virtual character.
 * This character indicates that the backlight has been toggled.
 */
#define vchrTelDevicePowerFinished (vchrDeviceSpecificChar + 5)
/** Tungsten W virtual character.
 * This character indicates that the backlight has been toggled.
 */
#define vchrBacklightToggled        (vchrDeviceSpecificChar + 6)
/** Tungsten W virtual character.
 * This character indicates that the space key has been pressed with the function key.
 */
#define vchrKeyboardSymbol   (vchrDeviceSpecificChar + 9)
/** Tungsten W virtual character.
 * This character indicates that a replace last char event has been triggered.
 * This occurs when an alpha numeric key is pressed and held.
 */
#define vchrReplaceLastChar   (vchrDeviceSpecificChar + 10)
/** Tungsten W virtual character.
 * This character indicates that a 5-way event has been triggered.
 */
#define vchrFunctionFiveWay   (vchrDeviceSpecificChar + 11)
/** Tungsten W virtual character.
 * This character indicates that an emergency call is being placed.
 * This occurs when the 4 hard keys are all pressed at once.
 */
#define vchrEmergencyCall   (vchrDeviceSpecificChar + 12)
/** Tungsten W virtual character.
 * This character indicates that a request to toggle the phone on or off has been made.
 */
#define vchrPowerOnPhone   (vchrDeviceSpecificChar + 14)




#endif // __PALMCHARS_H__




